@@ -4,7 +4,7 @@ package WebService::Avalara::AvaTax;
 
 use Modern::Perl '2011';    ## no critic (Modules::ProhibitUseQuotedVersion)
 
-our $VERSION = '0.011';     # VERSION
+our $VERSION = '0.012';     # VERSION
 use utf8;
 
 #pod =head1 SYNOPSIS
@@ -29,6 +29,8 @@ use utf8;
 
 use Carp;
 use Const::Fast;
+use DateTime;
+use DateTime::Format::XSD;
 use English '-no_match_vars';
 use Moo;
 use Package::Stash;
@@ -191,10 +193,8 @@ sub BUILD {
             %soap_params,
         );
         for my $operation ( $service->wsdl->operations(%soap_params) ) {
-
-            # normalize operation name into a Perl method name
             my $method_name = $operation->name;
-            if ( not $self->orthodox ) {
+            if ( not $self->orthodox ) {    # normalize operation name
                 $method_name
                     =~ s/ (?<= [[:alnum:]] ) ( [[:upper:]] ) /_\l$1/xmsg;
                 $method_name = lcfirst $method_name;
@@ -239,6 +239,10 @@ sub _method_closure {
         my $wsdl = $service->wsdl;
         $service->_current_operation_name( $operation->name );
 
+        if ( 'GetTax' eq $operation ) {
+            @parameters = _today_to_docdate(@parameters);
+        }
+
         my ( $answer_ref, $trace ) = $wsdl->call(
             $operation->name => {
                 Profile => {
@@ -264,6 +268,16 @@ sub _method_closure {
     };
 }
 
+sub _today_to_docdate {
+    my %parameters = @_;
+    if ( not defined $parameters{DocDate} ) {
+        $parameters{DocDate}
+            = DateTime::Format::XSD->format_datetime( DateTime->today );
+        $parameters{DocDate} =~ s/ T .* \z//xms;
+    }
+    return %parameters;
+}
+
 1;
 
 __END__
@@ -281,7 +295,7 @@ WebService::Avalara::AvaTax - Avalara SOAP interface as compiled Perl methods
 
 =head1 VERSION
 
-version 0.011
+version 0.012
 
 =head1 SYNOPSIS
 
@@ -365,6 +379,11 @@ that can be set at construction.
 
 I<< (SOAP operation: C<GetTax>) >>
 
+As a convenience to
+L<Business::Tax::Avalara|Business::Tax::Avalara>
+users (and others), the C<DocDate> element below will default to today's date
+in the UTC time zone.
+
 Constructing and making an example request:
 
     my %get_tax_request = (
@@ -409,14 +428,14 @@ Constructing and making an example request:
             TaxRegionId => 0,
         },
     );
-    for my $address_code (0 .. @addresses) {
+    for my $address_code (0 .. $#addresses) {
         push @{$get_tax_request{Addresses}{BaseAddress}} => {
             AddressCode => $address_code,
             %{ $addresses[$address_code] },
         };
     }
 
-    my @lines => (
+    my @lines = (
         {   OriginCode      => 0,
             DestinationCode => 1,
             ItemCode        => 'N543',
@@ -445,7 +464,7 @@ Constructing and making an example request:
             Description     => 'Shipping Charge',
         },
     );
-    for my $line_no (0 .. $#lines) {
+    for my $line_no (1 .. @lines) {
         push @{$get_tax_request{Lines}{Line}} => {
             No => $line_no,
             %{ $lines[$line_no - 1] },
